MsdFilter class

Constructors

MsdFilter(int manufacturerId, {List<int> data = const [], List<int>? mask = const []})

Properties

bm → BmMsdFilter
no setter
data List<int>
Filter for this data
final
hashCode int
The hash code for this object.
no setterinherited
manufacturerId int
final
mask List<int>?
Optional bitwise mask to define which bits in data must match. Must have the same length as data.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited