ScanResult class

Constructors

ScanResult({required String address, required String platformName, required AdvertisementData advertisementData, required int rssi, required DateTime timestamp})
ScanResult.fromProto(BmScanAdvertisement p)

Properties

address String
final
advertisementData AdvertisementData
final
device BluetoothDevice
no setter
hashCode int
The hash code for this object.
no setteroverride
platformName String
final
rssi int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

mergedWith(ScanResult newer) ScanResult
Returns this result updated with newer, carrying forward any field that newer does not carry.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override