Uuid class

A Bluetooth UUID which can be 16-bit, 32-bit, or 128-bit.

Constructors

Uuid(String input)
factory
Uuid.constant(List<int> bytes)
const
Uuid.fromBytes(List<int> bytes)

Properties

bytes List<int>
final
hashCode int
The hash code for this object.
no setteroverride
name String?
The human-readable name of this UUID if it is a well-known Bluetooth SIG assigned number (e.g. Uuid('2A24').name == 'Model Number String'), else null. See Uuids.nameOf.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
string String
no setter
string128 String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
Uuids are compared by value in their 128-bit form, so the same uuid expressed in short (16/32-bit) and long form compare equal.
override