BluebirdMockable class
Instance wrapper around the static Bluebird API so it can be mocked or
faked in tests. Every member simply forwards to the matching Bluebird
static; override them in a subclass or a mocking framework
(e.g. mocktail).
Constructors
Properties
-
adapterName
→ Future<
String> -
no setter
-
adapterState
→ AsyncValueStream<
BluetoothAdapterState> -
no setter
-
bondedDevices
→ Future<
List< BluetoothDevice> > -
no setter
-
connectedDevices
→ List<
BluetoothDevice> -
no setter
-
events
→ Stream<
BluebirdEvent> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isScanning
→ ValueStream<
bool> -
no setter
-
isSupported
→ Future<
bool> -
no setter
- platformLogLevel → LogLevel
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deviceForAddress(
String address) → BluetoothDevice -
getPhySupport(
) → Future< PhySupport> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
scan(
{List< Uuid> withServices = const [], List<String> withRemoteIds = const [], List<String> withNames = const [], List<String> withKeywords = const [], List<MsdFilter> withMsd = const [], List<ServiceDataFilter> withServiceData = const [], bool continuousUpdates = false, int continuousDivisor = 1, bool androidLegacy = false, AndroidScanMode androidScanMode = AndroidScanMode.lowLatency, bool androidUsesFineLocation = false, List<Uuid> webOptionalServices = const [], Duration? timeout}) → Stream<ScanResult> -
setOptions(
{bool showPowerAlert = true, bool restoreState = false}) → Future< void> -
setPlatformLogLevel(
LogLevel level) → Future< void> -
systemDevices(
List< Uuid> withServices) → Future<List< BluetoothDevice> > -
toString(
) → String -
A string representation of this object.
inherited
-
turnOn(
{Duration timeout = const Duration(seconds: 60)}) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited